<!-- warning: Please don't edit this file. It was automatically generated. -->

# winrt-Windows.Phone.Media.Devices

Windows Runtime (WinRT) APIs for for the `Windows.Phone.Media.Devices` namespace.

This package provides the `winrt.windows.phone.media.devices` module.
